==> fwupd_1.8.12.orig.tar.gz: fwupd-1.8.12/plugins/redfish/fu-redfish-device.h <==
/*
 * Copyright (C) 2021 Richard Hughes <richard@hughsie.com>
 *
 * SPDX-License-Identifier: LGPL-2.1+
 */

#pragma once

#include <fwupdplugin.h>

#include "fu-redfish-backend.h"

#define FU_TYPE_REDFISH_DEVICE (fu_redfish_device_get_type())
G_DECLARE_DERIVABLE_TYPE(FuRedfishDevice, fu_redfish_device, FU, REDFISH_DEVICE, FuDevice)

struct _FuRedfishDeviceClass {
	FuDeviceClass parent_class;
};

/**
 * FU_REDFISH_DEVICE_FLAG_IS_BACKUP:
 *
 * The device is the other half of a dual image firmware.
 */
#define FU_REDFISH_DEVICE_FLAG_IS_BACKUP (1 << 0)

/**
 * FU_REDFISH_DEVICE_FLAG_UNSIGNED_BUILD:
 *
 * Use unsigned development builds.
 */
#define FU_REDFISH_DEVICE_FLAG_UNSIGNED_BUILD (1 << 1)

/**
 * FU_REDFISH_DEVICE_FLAG_MANAGER_RESET:
 *
 * Reset the manager (typically the BMC) after updating this device.
 */
#define FU_REDFISH_DEVICE_FLAG_MANAGER_RESET (1 << 2)

/**
 * FU_REDFISH_DEVICE_FLAG_WILDCARD_TARGETS:
 *
 * Do not specify the `odata.id` in the multipart update Targets array and allow
 * the BMC to deploy the firmware onto all compatible hardware.
 *
 * To use this option the payload must contain metadata that restricts it to a
 * specific SoftwareId.
 */
#define FU_REDFISH_DEVICE_FLAG_WILDCARD_TARGETS (1 << 3)

FuRedfishBackend *
fu_redfish_device_get_backend(FuRedfishDevice *self);
gboolean
fu_redfish_device_poll_task(FuRedfishDevice *self,
			    const gchar *location,
			    FuProgress *progress,
			    GError **error);
guint
fu_redfish_device_get_reset_pre_delay(FuRedfishDevice *self);
guint
fu_redfish_device_get_reset_post_delay(FuRedfishDevice *self);

==> fwupd_1.9.33.orig.tar.gz: fwupd-1.9.33/plugins/redfish/fu-redfish-device.h <==
/*
 * Copyright (C) 2021 Richard Hughes <richard@hughsie.com>
 *
 * SPDX-License-Identifier: LGPL-2.1+
 */

#pragma once

#include <fwupdplugin.h>

#include "fu-redfish-backend.h"

#define FU_TYPE_REDFISH_DEVICE (fu_redfish_device_get_type())
G_DECLARE_DERIVABLE_TYPE(FuRedfishDevice, fu_redfish_device, FU, REDFISH_DEVICE, FuDevice)

struct _FuRedfishDeviceClass {
	FuDeviceClass parent_class;
};

/**
 * FU_REDFISH_DEVICE_FLAG_IS_BACKUP:
 *
 * The device is the other half of a dual image firmware.
 */
#define FU_REDFISH_DEVICE_FLAG_IS_BACKUP (1 << 0)

/**
 * FU_REDFISH_DEVICE_FLAG_UNSIGNED_BUILD:
 *
 * Use unsigned development builds.
 */
#define FU_REDFISH_DEVICE_FLAG_UNSIGNED_BUILD (1 << 1)

/**
 * FU_REDFISH_DEVICE_FLAG_MANAGER_RESET:
 *
 * Reset the manager (typically the BMC) after updating this device.
 */
#define FU_REDFISH_DEVICE_FLAG_MANAGER_RESET (1 << 2)

/**
 * FU_REDFISH_DEVICE_FLAG_WILDCARD_TARGETS:
 *
 * Do not specify the `odata.id` in the multipart update Targets array and allow
 * the BMC to deploy the firmware onto all compatible hardware.
 *
 * To use this option the payload must contain metadata that restricts it to a
 * specific SoftwareId.
 */
#define FU_REDFISH_DEVICE_FLAG_WILDCARD_TARGETS (1 << 3)

/**
 * FU_REDFISH_DEVICE_FLAG_NO_MANAGER_RESET_REQUEST:
 *
 * The BMC device will auto-reboot and so fwupd should not explicitly call
 * `/redfish/v1/Managers/1/Actions/Manager.Reset`.
 */
#define FU_REDFISH_DEVICE_FLAG_NO_MANAGER_RESET_REQUEST (1 << 4)

FuRedfishBackend *
fu_redfish_device_get_backend(FuRedfishDevice *self);
gboolean
fu_redfish_device_poll_task(FuRedfishDevice *self,
			    const gchar *location,
			    FuProgress *progress,
			    GError **error);
guint
fu_redfish_device_get_reset_pre_delay(FuRedfishDevice *self);
guint
fu_redfish_device_get_reset_post_delay(FuRedfishDevice *self);
